@@ -1,8 +1,13 @@
+// SPDX-FileCopyrightText: 2017 - 2023 Kamila Borowska <kamila@borowska.pw>
+// SPDX-FileCopyrightText: 2021 Bruno Corrêa Zimmermann <brunoczim@gmail.com>
+//
+// SPDX-License-Identifier: MIT OR Apache-2.0
+
 use crate::{enum_map, EnumArray, EnumMap};
 use core::fmt;
 use core::marker::PhantomData;
 use serde::de::{self, Deserialize, Deserializer, Error, MapAccess, SeqAccess};
-use serde::ser::{Serialize, SerializeMap, SerializeTuple, Serializer};
+use serde::ser::{Serialize, SerializeTuple, Serializer};
 
 /// Requires crate feature `"serde"`
 impl<K: EnumArray<V> + Serialize, V: Serialize> Serialize for EnumMap<K, V> {
